pub struct ErrorContext {
pub syscall: Syscall,
pub error: Errno,
}Expand description
Contains context to track the most recently failing system call.
When a task exits with a non-zero exit code, this context is logged to help debugging which system call may have triggered the failure.
Fields
syscall: SyscallThe system call that failed.
error: ErrnoThe error that was returned for the system call.